@@ -4,6 +4,9 @@
 #undef GUPPI_MINOR_VERSION
 #undef GUPPI_MICRO_VERSION
 #undef HAVE_GUILE
+#undef HAVE_HISTORY
+#undef HAVE_READLINE
+#undef READLINE_LIB
 #undef HAVE_LIBSM
 #undef HAVE_GUILE_GTK
 #undef HAVE_GUILE_GNOME
