@@ -1,4 +1,4 @@
-/* $Id: guppi-scatter-item.c,v 1.4 2000/01/25 15:47:35 trow Exp $ */
+/* $Id: guppi-scatter-item.c,v 1.7 2000/02/21 18:34:22 trow Exp $ */
 
 /*
  * guppi-scatter-item.c
@@ -58,8 +58,8 @@ guppi_scatter_item_reset_x_bounds(GuppiScatterItem* si)
   g_return_if_fail(si != NULL);
   if (si->state && si->state->x_data)
     guppi_canvas_item_set_x_bounds(GUPPI_CANVAS_ITEM(si),
-				   guppi_scalar_data_min(si->state->x_data),
-				   guppi_scalar_data_max(si->state->x_data));
+				   guppi_seq_scalar_min(si->state->x_data),
+				   guppi_seq_scalar_max(si->state->x_data));
 }
 
 static void
@@ -68,8 +68,8 @@ guppi_scatter_item_reset_y_bounds(GuppiScatterItem* si)
   g_return_if_fail(si != NULL);
   if (si->state && si->state->y_data)
     guppi_canvas_item_set_y_bounds(GUPPI_CANVAS_ITEM(si),
-				   guppi_scalar_data_min(si->state->y_data),
-				   guppi_scalar_data_max(si->state->y_data));
+				   guppi_seq_scalar_min(si->state->y_data),
+				   guppi_seq_scalar_max(si->state->y_data));
 }
 
 
@@ -89,13 +89,9 @@ guppi_scatter_item_update(GnomeCanvasItem* item, double affine[6],
   if (si->state->x_data == NULL || si->state->y_data == NULL)
     return;
 
-  if (si->mask1)
-    gtk_object_unref(GTK_OBJECT(si->mask1));
-  si->mask1 = GUPPI_BOOLEAN_DATA(guppi_boolean_data_new_aligned(GUPPI_DATA(si->state->x_data)));
-
-  if (si->mask2)
-    gtk_object_unref(GTK_OBJECT(si->mask2));
-  si->mask2 = GUPPI_BOOLEAN_DATA(guppi_boolean_data_new_aligned(GUPPI_DATA(si->state->y_data)));
+  if (si->vis_mask)
+    gtk_object_unref(GTK_OBJECT(si->vis_mask));
+  si->vis_mask = GUPPI_SEQ_BOOLEAN(guppi_seq_boolean_new_aligned(GUPPI_SEQ(si->state->x_data)));
 
   guppi_canvas_item_request_total_redraw(GUPPI_CANVAS_ITEM(item));
 }
@@ -110,9 +106,9 @@ guppi_scatter_item_render(GnomeCanvasItem* item,
   GuppiScatterStyle* style;
   gint fuzz=5;
   gboolean got_hits = TRUE;
-  gboolean tainted;
   gint i;
   double xmag, ymag, scale_factor;
+  GuppiSeqBoolean* vis_mask_copy;
 
   /* Chain our calls to render */
   if (parent_class && GNOME_CANVAS_ITEM_CLASS(parent_class)->render)
@@ -156,26 +152,22 @@ guppi_scatter_item_render(GnomeCanvasItem* item,
 
   /* Perform our window query and build up a bit mask indicating which
      points we need to draw. */
-  guppi_boolean_data_clear(si->mask1);
-  got_hits = (0 != guppi_scalar_data_range_query(si->state->x_data,
-						   rx0, rx1, si->mask1));
+  guppi_seq_boolean_clear(si->vis_mask);
+  got_hits = guppi_seq_scalar_in_place_range_query(si->state->x_data,
+						   si->vis_mask,
+						   rx0, rx1);
   if (got_hits) {
-    guppi_boolean_data_clear(si->mask2);
-    got_hits = (0 != guppi_scalar_data_range_query(si->state->y_data,
-						   ry0, ry1, si->mask2));
+    got_hits = guppi_seq_scalar_bitwise_and_range_query(si->state->y_data,
+							si->vis_mask,
+							ry0, ry1);
   }
     
   if (got_hits) {
-    guppi_boolean_data_logical_and(si->mask1, si->mask2);
-    guppi_boolean_data_replace(si->mask2, si->mask1);
-    tainted = FALSE;
-    /* Now both si->mask1 and si->mask2 contain the same thing, the bitmask
-       of our windowed data */
-
+    
     for (i=0; i<GUPPI_SCATTER_STATE_STYLE_COUNT; ++i) {
 
-      /* We let the base mask 0 through, and don't interfere with si->mask1
-	 if mask[0] if NULL.  When no brushing is active, the extra
+      /* We let the base mask 0 through, and don't interfere with si->vis_mask
+	 if mask[i] if NULL.  When no brushing is active, the extra
 	 overhead of looping and testing all of the mask[i]'s (which will
 	 all be NULL) should be totally negligable. */
 
@@ -185,12 +177,12 @@ guppi_scatter_item_render(GnomeCanvasItem* item,
 	if (style == NULL)
 	  g_error("Evil stalks the land");
 
-	/* Our tainted flag lets us avoid extra copies */
-	if (tainted)
-	  guppi_boolean_data_replace(si->mask1, si->mask2);
 	if (si->state->mask[i]) {
-	  guppi_boolean_data_logical_and(si->mask1, si->state->mask[i]);
-	  tainted = TRUE;
+	  vis_mask_copy = GUPPI_SEQ_BOOLEAN(guppi_data_copy(GUPPI_DATA(si->vis_mask)));
+	  guppi_seq_boolean_bitwise_and(vis_mask_copy, si->state->mask[i]);
+	} else {
+	  vis_mask_copy = si->vis_mask;
+	  gtk_object_ref(GTK_OBJECT(si->vis_mask));
 	}
 
 	guppi_scatter_style_paint(style,
@@ -200,8 +192,9 @@ guppi_scatter_item_render(GnomeCanvasItem* item,
 				  buf->rect.x0, buf->rect.y0,
 				  gci->x_transform, gci->y_transform,
 				  si->state->x_data, si->state->y_data,
-				  si->mask1,
+				  vis_mask_copy,
 				  scale_factor);
+	gtk_object_unref(GTK_OBJECT(vis_mask_copy));
 
       }
     }
@@ -302,8 +295,7 @@ static void
 guppi_scatter_item_init(GuppiScatterItem* si)
 {
   si->state = NULL;
-  si->mask1 = NULL;
-  si->mask2 = NULL;
+  si->vis_mask = NULL;
 
   gtk_signal_connect(GTK_OBJECT(si),
 		     "event",
@@ -365,4 +357,4 @@ guppi_scatter_item_set_state(GuppiScatterItem* si,
 
 
 
-/* $Id: guppi-scatter-item.c,v 1.4 2000/01/25 15:47:35 trow Exp $ */
+/* $Id: guppi-scatter-item.c,v 1.7 2000/02/21 18:34:22 trow Exp $ */
