@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-scatter-style.c,v 1.9 2000/01/21 17:07:47 trow Exp $ */
+/* $Id: guppi-scatter-style.c,v 1.11 2000/02/11 19:45:11 trow Exp $ */
 
 /*
  * guppi-scatter-style.c
@@ -27,8 +27,8 @@
 
 #include <ctype.h>
 #include <math.h>
+#include <guppi-rgb.h>
 #include "guppi-scatter-style.h"
-#include "rgb.h"
 #ifdef BENCH
 #include <sys/time.h>
 #include <unistd.h>
@@ -510,7 +510,7 @@ guppi_scatter_style_set_color(GuppiScatterStyle* sty, guint32 col)
 
 void
 guppi_scatter_style_set_gradient_data(GuppiScatterStyle* sty,
-				      GuppiScalarData* data)
+				      GuppiSeqScalar* data)
 {
   g_return_if_fail(sty != NULL);
 
@@ -558,7 +558,7 @@ guppi_scatter_style_set_reverse_color_gradient(GuppiScatterStyle* sty,
 }
 
 void
-guppi_scatter_style_set_size1_data(GuppiScatterStyle* sty, GuppiScalarData* d)
+guppi_scatter_style_set_size1_data(GuppiScatterStyle* sty, GuppiSeqScalar* d)
 {
   g_return_if_fail(sty != NULL);
 
@@ -608,7 +608,7 @@ guppi_scatter_style_set_reverse_size1_gradient(GuppiScatterStyle* sty,
 
 
 void
-guppi_scatter_style_set_size2_data(GuppiScatterStyle* sty, GuppiScalarData* d)
+guppi_scatter_style_set_size2_data(GuppiScatterStyle* sty, GuppiSeqScalar* d)
 {
   g_return_if_fail(sty != NULL);
 
@@ -670,9 +670,9 @@ guppi_scatter_style_paint(GuppiScatterStyle* sty,
 			  gint w, gint h, gint adj_x, gint adj_y,
 			  const Transform* x_transform,
 			  const Transform* y_transform,
-			  const GuppiScalarData* x_data,
-			  const GuppiScalarData* y_data,
-			  const GuppiBooleanData* mask,
+			  const GuppiSeqScalar* x_data,
+			  const GuppiSeqScalar* y_data,
+			  const GuppiSeqBoolean* mask,
 			  double scale_factor)
 {
 #ifdef BENCH
@@ -696,7 +696,7 @@ guppi_scatter_style_paint(GuppiScatterStyle* sty,
   
   gint x, y;
   gint xtweak=0, ytweak=0;
-  dindex_t k, k_max;
+  gint k, k_max;
 
   g_return_if_fail(sty != NULL);
   g_return_if_fail(rgb_buffer != NULL);
@@ -720,15 +720,15 @@ guppi_scatter_style_paint(GuppiScatterStyle* sty,
 
   if (do_gradient_coloring) {
     UINT_TO_RGBA(sty->color_low, &rlo, &glo, &blo, &alo);
-    grad_min = guppi_scalar_data_min(sty->gradient_data);
-    grad_max = guppi_scalar_data_max(sty->gradient_data);
+    grad_min = guppi_seq_scalar_min(sty->gradient_data);
+    grad_max = guppi_seq_scalar_max(sty->gradient_data);
     if (grad_min == grad_max)
       do_gradient_coloring = FALSE;
   }
   
   if (do_size1_gradient) {
-    size1_grad_min = guppi_scalar_data_min(sty->size1_data);
-    size1_grad_max = guppi_scalar_data_max(sty->size1_data);
+    size1_grad_min = guppi_seq_scalar_min(sty->size1_data);
+    size1_grad_max = guppi_seq_scalar_max(sty->size1_data);
 
     /* A hack, for now */
     sty->size1_high = 5*sty->size1;
@@ -738,8 +738,8 @@ guppi_scatter_style_paint(GuppiScatterStyle* sty,
   }
 
   if (do_size2_gradient) {
-    size2_grad_min = guppi_scalar_data_min(sty->size2_data);
-    size2_grad_max = guppi_scalar_data_max(sty->size2_data);
+    size2_grad_min = guppi_seq_scalar_min(sty->size2_data);
+    size2_grad_max = guppi_seq_scalar_max(sty->size2_data);
 
     /* A hack, for now */
     sty->size2_high = 4*sty->size2;
@@ -773,22 +773,22 @@ guppi_scatter_style_paint(GuppiScatterStyle* sty,
 #endif
     
   if (mask != NULL) 
-    k = guppi_boolean_data_first_true(mask);
+    k = guppi_seq_boolean_first_true(mask);
   else
-    k = guppi_data_min_index(GUPPI_DATA(x_data));
+    k = guppi_seq_min_index(GUPPI_SEQ(x_data));
 
-  k_max = guppi_data_max_index(mask ? GUPPI_DATA(mask) : GUPPI_DATA(x_data));
+  k_max = guppi_seq_max_index(mask ? GUPPI_SEQ(mask) : GUPPI_SEQ(x_data));
 
   while (k <= k_max) {
 
     x = transform_plot2pixel_unsafe(x_transform,
-				    guppi_scalar_data_get(x_data, k));
+				    guppi_seq_scalar_get(x_data, k));
 
     y = transform_plot2pixel_unsafe(y_transform,
-				    guppi_scalar_data_get(y_data, k));
+				    guppi_seq_scalar_get(y_data, k));
 
     if (do_gradient_coloring) {
-      grad = guppi_scalar_data_get_unsafe(sty->gradient_data, k);
+      grad = guppi_seq_scalar_get(sty->gradient_data, k);
       grad = (grad-grad_min)/(grad_max-grad_min);
       if (sty->reverse_color_gradient)
 	grad = 1 - grad;
@@ -800,7 +800,7 @@ guppi_scatter_style_paint(GuppiScatterStyle* sty,
     }
 
     if (do_size1_gradient) {
-      size1_now = guppi_scalar_data_get_unsafe(sty->size1_data, k);
+      size1_now = guppi_seq_scalar_get(sty->size1_data, k);
       size1_now = (size1_now - size1_grad_min)/(size1_grad_max-size1_grad_min);
       if (sty->reverse_size1_gradient)
 	size1_now = 1 - size1_now;
@@ -808,7 +808,7 @@ guppi_scatter_style_paint(GuppiScatterStyle* sty,
     }
 
     if (do_size2_gradient) {
-      size2_now = guppi_scalar_data_get_unsafe(sty->size2_data, k);
+      size2_now = guppi_seq_scalar_get(sty->size2_data, k);
       size2_now = (size2_now - size2_grad_min)/(size2_grad_max-size2_grad_min);
       if (sty->reverse_size2_gradient)
 	size2_now = 1 - size2_now;
@@ -895,7 +895,7 @@ guppi_scatter_style_paint(GuppiScatterStyle* sty,
     }
 
     if (mask)
-      k = guppi_boolean_data_next_true(mask, k);
+      k = guppi_seq_boolean_next_true(mask, k);
     else
       ++k;
 
@@ -920,4 +920,4 @@ guppi_scatter_style_paint(GuppiScatterStyle* sty,
 									      
 				  
 
-/* $Id: guppi-scatter-style.c,v 1.9 2000/01/21 17:07:47 trow Exp $ */
+/* $Id: guppi-scatter-style.c,v 1.11 2000/02/11 19:45:11 trow Exp $ */
