@@ -1,4 +1,4 @@
-/* $Id: guppi-data-init.c,v 1.3 2000/01/19 15:45:09 trow Exp $ */
+/* $Id: guppi-data-init.c,v 1.5 2000/02/09 21:04:56 trow Exp $ */
 
 /*
  * guppi-data-init.c
@@ -24,39 +24,18 @@
  * USA
  */
 
-#include "guppi-scm-dataset.h"
-#include "guppi-scm-data.h"
-#include "guppi-scm-scalar-data.h"
-#include "guppi-scm-boolean-data.h"
-#include "guppi-scm-categorical-data.h"
-#include "guppi-scm-string-data.h"
-#include "guppi-scm-data-catalog.h"
-#include "guppi-scm-importer.h"
-#include "guppi-scm-delimited-importer.h"
 #include "guppi-data-init.h"
+#include "guppi-scm-data.h"
 
 void
 guppi_data_init(void)
 {
-  /* Make sure all of our data types "exist". */
-  guppi_data_get_type();
-  guppi_scalar_data_get_type();
-  guppi_boolean_data_get_type();
-  guppi_categorical_data_get_type();
-  guppi_string_data_get_type();
+  static gboolean inited = FALSE;
+  g_return_if_fail(!inited);
+  inited = TRUE;
 
-  /* Initialize our scheme bindings. */
-  guppi_scm_dataset_init();
   guppi_scm_data_init();
-  guppi_scm_scalar_data_init();
-  guppi_scm_boolean_data_init();
-  guppi_scm_categorical_data_init();
-  guppi_scm_string_data_init();
-
-  guppi_scm_data_catalog_init();
-  guppi_scm_importer_init();
-  guppi_scm_delimited_importer_init();
 }
 
 
-/* $Id: guppi-data-init.c,v 1.3 2000/01/19 15:45:09 trow Exp $ */
+/* $Id: guppi-data-init.c,v 1.5 2000/02/09 21:04:56 trow Exp $ */
