@@ -1,11 +1,11 @@
-/* $Id: guppi-canvas-item.c,v 1.6 2000/01/24 20:49:36 trow Exp $ */
+/* $Id: guppi-canvas-item.c,v 1.7 2000/02/10 02:05:31 trow Exp $ */
 
 /*
  * guppi-canvas-item.c
  *
  * Copyright (C) 1999 EMC Capital Management, Inc.
  *
- * Developed by Jon Trowbridge <trow@emccta.com> and 
+ * Developed by Jon Trowbridge <trow@gnu.org> and 
  * Havoc Pennington <hp@pobox.com>.
  *
  * This program is free software; you can redistribute it and/or
@@ -25,7 +25,7 @@
  */
 
 #include <config.h>
-#include "rgb.h"
+#include <guppi-rgb.h>
 #include "guppi-canvas-item.h"
 
 enum {
@@ -831,6 +831,6 @@ guppi_canvas_item_request_update(GuppiCanvasItem* gci)
   gnome_canvas_item_request_update(GNOME_CANVAS_ITEM(gci));
 }
 
-/* $Id: guppi-canvas-item.c,v 1.6 2000/01/24 20:49:36 trow Exp $ */
+/* $Id: guppi-canvas-item.c,v 1.7 2000/02/10 02:05:31 trow Exp $ */
 
 
