@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-canvas-item.h,v 1.4 2000/01/21 06:14:38 trow Exp $ */
+/* $Id: guppi-canvas-item.h,v 1.5 2000/02/06 03:14:54 trow Exp $ */
 
 /*
  * guppi-canvas-item.h
@@ -30,8 +30,6 @@
 
 #include <config.h>
 #include <gnome.h>
-#include <guppi-scalar-data.h>
-#include <guppi-boolean-data.h>
 #include "transform.h"
 #include "guppi-bounder.h"
 #include "guppi-item-state.h"
@@ -138,4 +136,4 @@ void guppi_canvas_item_request_update(GuppiCanvasItem*);
 
 #endif /* _INC_GUPPI_CANVAS_ITEM_H */
 
-/* $Id: guppi-canvas-item.h,v 1.4 2000/01/21 06:14:38 trow Exp $ */
+/* $Id: guppi-canvas-item.h,v 1.5 2000/02/06 03:14:54 trow Exp $ */
