@@ -30,6 +30,7 @@
 #include <guile-gtk.h> 
 #endif
 
+#include "guppi-rgb.h"
 #include "guppi-splash.h"
 #include "guppi-guile.h"
 
@@ -419,6 +420,7 @@ guppi_eval_str (const char *exp)
 
 /* These two functions are also in ../corba_guppi.cc, which is lame. */
 
+#ifdef USE_UNUSED
 static SCM make_output_strport(char *fname)
 {
   return scm_mkstrport(SCM_INUM0, scm_make_string(SCM_MAKINUM(30), 
@@ -426,8 +428,9 @@ static SCM make_output_strport(char *fname)
                        SCM_OPN | SCM_WRTNG,
                        fname);
 }
+#endif
 
-
+#ifdef USE_UNUSED
 static SCM get_strport_string(SCM port)
 {
   /*  SCM answer; */
@@ -447,6 +450,7 @@ static SCM get_strport_string(SCM port)
   return answer;
   */
 }
+#endif
 
 /* OutputContext is an abstraction for evaling an expression
    and collecting its output.*/
@@ -456,6 +460,7 @@ struct OutputContext {
   SCM saved_def_e_port;
 };
 
+#ifdef USE_UNUSED
 static void
 init_output_context(struct OutputContext* oc)
 {       
@@ -468,9 +473,8 @@ init_output_context(struct OutputContext* oc)
   /* Workaround for a problem with older Guiles */
   oc->saved_def_e_port = scm_def_errp;
   scm_def_errp = scm_current_error_port();
-  
-
 }
+#endif
 
 /* These could both be made faster, but this is fine for small enums */
 gboolean
@@ -530,6 +534,208 @@ guppi_scm_eval_cb(gpointer widget, gpointer eval_str)
   guppi_eval_str((const gchar*)eval_str);
 }
 
+/****************************************************************************/
+
+gboolean
+scm_stringv_p(SCM x)
+{
+  if (!gh_list_p(x))
+    return FALSE;
+  
+  while (!gh_null_p(x)) {
+    if (!gh_string_p(gh_car(x)))
+      return FALSE;
+    x = gh_cdr(x);
+  }
+  return TRUE;
+}
+
+SCM
+stringv2scm(gchar** vec)
+{
+  SCM x = SCM_EOL;
+  gint i=0;
+  if (vec == NULL)
+    return SCM_EOL;
+  while (vec[i]) ++i;
+  --i;
+  while (i>=0) {
+    x = gh_cons(gh_str02scm(vec[i]), x);
+    --i;
+  }
+  return x;
+}
+
+gchar**
+scm2stringv(SCM x)
+{
+  SCM y=x;
+  gchar** v;
+  gint i=0;
+  while (!gh_null_p(y)) {
+    ++i;
+    y=gh_cdr(y);
+  }
+  v = g_new(gchar*, i+1);
+  v[i] = NULL;
+  while (!gh_null_p(x)) {
+    --i;
+    v[i] = gh_scm2newstr(x, NULL);
+    x = gh_cdr(x);
+  }
+  return v;
+}
+
+static SCM
+scm_fn_stringv_p(SCM x)
+{
+  return gh_bool2scm(scm_stringv_p(x));
+}
+
+gboolean
+scm_color_p(SCM x)
+{
+  if (gh_exact_p(x)) {
+    gint c;
+    c = gh_scm2int(x);
+    return (c >= 0);
+  }
+
+  if (gh_string_p(x)) {
+    gchar* s;
+    gboolean flag;
+    GdkColor col;
+    s = gh_scm2newstr(x, NULL);
+    flag = gdk_color_parse(s, &col);
+    g_free(s);
+    return flag;
+  }
+
+  if (gh_list_p(x)) {
+    SCM y;
+    gint len;
+    gint r,g,b,a;
+    len = gh_length(x);
+    if (len < 3 || len > 4)
+      return FALSE;
+
+    y = gh_car(x);
+    if (!gh_exact_p(y)) return FALSE;
+    r = gh_scm2int(y);
+    if (r<0 || r>0xff) return FALSE;
+    x = gh_cdr(x);
+
+    y = gh_car(x);
+    if (!gh_exact_p(y)) return FALSE;
+    g = gh_scm2int(y);
+    if (g<0 || g>0xff) return FALSE;
+    x = gh_cdr(x);
+
+    y = gh_car(x);
+    if (!gh_exact_p(y)) return FALSE;
+    b = gh_scm2int(y);
+    if (b<0 || b>0xff) return FALSE;
+    x = gh_cdr(x);
+
+    if (len == 4) {
+      y = gh_car(x);
+      if (!gh_exact_p(y)) return FALSE;
+      a = gh_scm2int(y);
+      if (a<0 || a>0xff) return FALSE;
+      x = gh_cdr(x);
+    }
+    return TRUE;
+  }
+
+  return FALSE;
+}
+
+SCM
+color2scm(guint32 color)
+{
+  gint r,g,b,a;
+  SCM x = SCM_EOL;
+
+  UINT_TO_RGBA(color, &r, &g, &b, &a);
+  
+  x = gh_cons(gh_int2scm(a), x);
+  x = gh_cons(gh_int2scm(b), x);
+  x = gh_cons(gh_int2scm(g), x);
+  x = gh_cons(gh_int2scm(r), x);
+
+  return x;
+}
+
+guint32
+scm2color(SCM x)
+{
+  if (gh_exact_p(x)) {
+    gint c;
+    c = gh_scm2int(x);
+    return (c >= 0) ? c : 0;
+  }
+
+  if (gh_string_p(x)) {
+    gchar* s;
+    gboolean flag;
+    GdkColor col;
+    s = gh_scm2newstr(x, NULL);
+    flag = gdk_color_parse(s, &col);
+    g_free(s);
+
+    return RGBA_TO_UINT(col.red>>8,col.green>>8,col.blue>>8,0xff);
+  }
+
+  if (gh_list_p(x)) {
+    SCM y;
+    gint len;
+    gint r,g,b,a;
+    len = gh_length(x);
+    if (len < 3 || len > 4)
+      return FALSE;
+
+    y = gh_car(x);
+    if (!gh_exact_p(y)) return 0;
+    r = gh_scm2int(y);
+    if (r<0 || r>0xff) return 0;
+    x = gh_cdr(x);
+
+    y = gh_car(x);
+    if (!gh_exact_p(y)) return 0;
+    g = gh_scm2int(y);
+    if (g<0 || g>0xff) return 0;
+    x = gh_cdr(x);
+
+    y = gh_car(x);
+    if (!gh_exact_p(y)) return 0;
+    b = gh_scm2int(y);
+    if (b<0 || b>0xff) return 0;
+    x = gh_cdr(x);
+
+    a = 0xff;
+    if (len == 4) {
+      y = gh_car(x);
+      if (!gh_exact_p(y)) return 0;
+      a = gh_scm2int(y);
+      if (a<0 || a>0xff) return 0;
+      x = gh_cdr(x);
+    } 
+    
+    return RGBA_TO_UINT(r,g,b,a);
+  }
+
+  return FALSE;
+  
+}
+
+static SCM
+scm_fn_color_p(SCM x)
+{
+  return gh_bool2scm(scm_color_p(x));
+}
+
+/****************************************************************************/
+
 void 
 guppi_guile_init(void)
 {
@@ -538,7 +744,11 @@ guppi_guile_init(void)
   init = TRUE;
 
   guppi_splash_message("Initializing Guile");
-#include "guppi-guile.x"
+  gh_eval_str("(use-modules (ice-9 readline) (ice-9 session))");
+  gh_eval_str("(activate-readline)");
+
+  scm_make_gsubr("stringv?", 1, 0, 0, scm_fn_stringv_p);
+  scm_make_gsubr("color?", 1, 0, 0, scm_fn_color_p);
 
 #ifdef USING_GUILE_GNOME_BINDINGS
   guppi_splash_message("Loading guile-gtk");
