@@ -1,4 +1,4 @@
-/* $Id: guppi-splash.c,v 1.1 2000/01/17 05:44:56 trow Exp $ */
+/* $Id: guppi-splash.c,v 1.2 2000/02/11 07:25:39 trow Exp $ */
 
 /*
  * guppi-splash.c
@@ -124,16 +124,18 @@ guppi_splash_destroy(void)
 void
 guppi_splash_message(const gchar* text)
 {
-  g_return_if_fail(splash != NULL);
   g_return_if_fail(text != NULL);
 
-  gtk_catchup();
-
-  gtk_label_set_text(GTK_LABEL(splash_label), (gchar*)text);
+  if (splash) {
+    gtk_catchup();
+    gtk_label_set_text(GTK_LABEL(splash_label), (gchar*)text);
+  }
   g_message(text);
 
-  gtk_catchup();
+  if (splash) {
+    gtk_catchup();
+  }
 }
 
 
-/* $Id: guppi-splash.c,v 1.1 2000/01/17 05:44:56 trow Exp $ */
+/* $Id: guppi-splash.c,v 1.2 2000/02/11 07:25:39 trow Exp $ */
