@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-stream.c,v 1.2 2000/01/20 18:48:24 trow Exp $ */
+/* $Id: guppi-stream.c,v 1.5 2000/02/21 18:26:21 trow Exp $ */
 
 /*
  * guppi-stream.c
@@ -76,8 +76,10 @@ guppi_stream_finalize(GtkObject* obj)
   GuppiStream* gs = GUPPI_STREAM(obj);
   gint i;
 
-  g_free(gs->filename);
-  g_free(gs->label);
+  if (gs->in) {
+    guppi_file_close(gs->in);
+    gs->in = NULL;
+  }
 
   if (gs->buffer) {
     for(i=0; i<gs->buffer_top; ++i) {
@@ -150,8 +152,6 @@ static void
 guppi_stream_init(GuppiStream* gs)
 {
   gs->in = NULL;
-  gs->filename = NULL;
-  gs->label = NULL;
 
   gs->bad = FALSE;
   gs->buffering = TRUE;
@@ -203,7 +203,7 @@ guppi_stream_get_type(void)
 }
 
 GuppiStream*
-guppi_stream_new(FILE* f)
+guppi_stream_new(GuppiFile* f)
 {
   GuppiStream* gs;
   struct stat stat;
@@ -213,8 +213,9 @@ guppi_stream_new(FILE* f)
   gs = GUPPI_STREAM(gtk_type_new(guppi_stream_get_type()));
 
   gs->in = f;
+  gtk_object_ref(GTK_OBJECT(gs->in));
   
-  if (fstat(fileno(gs->in), &stat) == 0) {
+  if (guppi_file_stat(gs->in, &stat) == 0) {
     gs->total_size = stat.st_size;
   }
 
@@ -224,17 +225,17 @@ guppi_stream_new(FILE* f)
 GuppiStream*
 guppi_stream_open_file(const gchar* filename)
 {
-  FILE* in;
+  GuppiFile* in;
   GuppiStream* gs;
 
   g_return_val_if_fail(filename != NULL, NULL);
 
-  in = fopen(filename, "r");
+  in = guppi_file_open(filename);
   if (in == NULL)
     return NULL;
 
   gs = guppi_stream_new(in);
-  gs->filename = g_strdup(filename);
+  gtk_object_unref(GTK_OBJECT(in));
   
   return gs;
 }
@@ -573,12 +574,7 @@ const gchar*
 guppi_stream_source(GuppiStream* gs)
 {
   g_return_val_if_fail(gs != NULL, NULL);
-  if (gs->label)
-    return gs->label;
-  else if (gs->filename)
-    return gs->filename;
-  else 
-    return NULL;
+  return guppi_file_filename(gs->in);
 }
 
 gint
@@ -586,7 +582,7 @@ guppi_stream_number_of_lines(GuppiStream* gs)
 {
   g_return_val_if_fail(gs != NULL, -1);
 
-  return gs->buffering ? 1+gs->current_line_no : -1;
+  return gs->buffering && gs->eof ? 1+gs->current_line_no : -1;
 }
 
 gint
@@ -595,7 +591,7 @@ guppi_stream_estimated_number_of_lines(GuppiStream* gs)
   g_return_val_if_fail(gs != NULL, -1);
 
   if (gs->buffering && gs->eof)
-    return gs->current_line_no;
+    return 1+gs->current_line_no;
 
   if (gs->total_size > 0) {
     if (gs->current_line > 0 &&
@@ -698,7 +694,7 @@ guppi_stream_get_lines_through(GuppiStream* gs, gint line_no)
   
   while (!gs->eof && gs->current_line_no < line_no) {
 
-    if (fgets(buf, buflen, gs->in)) {
+    if (guppi_file_gets(gs->in, buf, buflen)) {
       
       g_strchomp(buf);
       did_something = TRUE;
@@ -726,11 +722,15 @@ guppi_stream_get_lines_through(GuppiStream* gs, gint line_no)
       }
     } else {
       gs->eof = TRUE;
-      fclose(gs->in);
+      /*
+      guppi_file_close(gs->in);
+      gtk_object_unref(GTK_OBJECT(gs->in));
       gs->in = NULL;
+      */
       if (gs->buffering) {
 	gtk_signal_emit(GTK_OBJECT(gs), str_signals[FULLY_PRELOADED]);
-	gs->total_size = gs->buffered_size;
+	if (gs->total_size < 0)
+	  gs->total_size = gs->buffered_size;
       }
     }
   }
@@ -849,4 +849,4 @@ guppi_stream_load_more_lines(GuppiStream* gs)
 
 
 
-/* $Id: guppi-stream.c,v 1.2 2000/01/20 18:48:24 trow Exp $ */
+/* $Id: guppi-stream.c,v 1.5 2000/02/21 18:26:21 trow Exp $ */
