@@ -24,16 +24,18 @@
 
 #include "guppi-useful.h"
 #include "guppi-scm-useful.h"
-#include "guppi-scm-stream.h"
 
 void
 guppi_useful_init(void)
 {
   guppi_guile_init();
   guppi_scm_useful_init();
-  guppi_scm_stream_init();
+
+  /* Try to insure that we can't gracelessly shutdown the whole process
+     from guile. */
+  gh_eval_str("(define exit guppi-exit)");
 }
 
 
 
-/* $Id: guppi-useful.c,v 1.1 2000/01/17 05:44:56 trow Exp $ */
+/* $Id: guppi-useful.c,v 1.3 2000/02/11 07:27:42 trow Exp $ */
