@@ -1,4 +1,4 @@
-/* $Id: guppi-useful.h,v 1.1 2000/01/17 05:44:56 trow Exp $ */
+/* $Id: guppi-useful.h,v 1.5 2000/02/16 22:48:26 trow Exp $ */
 
 /*
  * guppi-useful.h
@@ -27,15 +27,21 @@
 #ifndef _INC_GUPPI_USEFUL_H
 #define _INC_GUPPI_USEFUL_H
 
-#include <guppi-splash.h>
-#include <guppi-paths.h>
 #include <guppi-debug.h>
-#include <guppi-guile.h>
+#include <guppi-file.h>
 #include <guppi-exit.h>
+#include <guppi-guile.h>
+#include <guppi-paths.h>
+#include <guppi-plug-in.h>
+#include <guppi-rgb.h>
+#include <guppi-splash.h>
 #include <guppi-stream.h>
+#include <guppi-stream-preview.h>
+#include <guppi-string.h>
+#include <guppi-version.h>
 
 void guppi_useful_init(void);
 
 #endif /* _INC_GUPPI_USEFUL_H */
 
-/* $Id: guppi-useful.h,v 1.1 2000/01/17 05:44:56 trow Exp $ */
+/* $Id: guppi-useful.h,v 1.5 2000/02/16 22:48:26 trow Exp $ */
